@@ -1,3 +1,13 @@
+/*
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * Copyright (C) 2014 Karel Zak <kzak@redhat.com>
+ */
 #include <libfdisk.h>
 #include <libsmartcols.h>
 #include <assert.h>
@@ -26,7 +36,7 @@ static int is_ide_cdrom_or_tape(char *device)
 {
 	int fd, ret;
 
-	if ((fd = open(device, O_RDONLY)) < 0)
+	if ((fd = open(device, O_RDONLY|O_NONBLOCK)) < 0)
 		return 0;
 	ret = blkdev_is_cdrom(fd);
 
@@ -53,7 +63,8 @@ void list_disk_geometry(struct fdisk_context *cxt)
 {
 	struct fdisk_label *lb = fdisk_get_label(cxt, NULL);
 	uint64_t bytes = fdisk_get_nsectors(cxt) * fdisk_get_sector_size(cxt);
-	char *strsz = size_to_human_string(SIZE_SUFFIX_SPACE
+	char *strsz = size_to_human_string(SIZE_DECIMAL_2DIGITS
+					   | SIZE_SUFFIX_SPACE
 					   | SIZE_SUFFIX_3LETTER, bytes);
 
 	color_scheme_enable("header", UL_COLOR_BOLD);
@@ -67,10 +78,10 @@ void list_disk_geometry(struct fdisk_context *cxt)
 		fdisk_info(cxt, _("Disk model: %s"), fdisk_get_devmodel(cxt));
 
 	if (lb && (fdisk_label_require_geometry(lb) || fdisk_use_cylinders(cxt)))
-		fdisk_info(cxt, _("Geometry: %d heads, %llu sectors/track, %llu cylinders"),
+		fdisk_info(cxt, _("Geometry: %d heads, %ju sectors/track, %ju cylinders"),
 			       fdisk_get_geom_heads(cxt),
-			       fdisk_get_geom_sectors(cxt),
-			       fdisk_get_geom_cylinders(cxt));
+			       (uintmax_t) fdisk_get_geom_sectors(cxt),
+			       (uintmax_t) fdisk_get_geom_cylinders(cxt));
 
 	fdisk_info(cxt, _("Units: %s of %d * %ld = %ld bytes"),
 	       fdisk_get_unit(cxt, FDISK_PLURAL),
@@ -181,7 +192,7 @@ void list_disklabel(struct fdisk_context *cxt)
 
 	/* print */
 	if (!scols_table_is_empty(out)) {
-		fdisk_info(cxt, "");	/* just line break */
+		fdisk_info(cxt, "%s", "");	/* just line break */
 		scols_print_table(out);
 	}
 
@@ -192,23 +203,24 @@ void list_disklabel(struct fdisk_context *cxt)
 			continue;
 		if (!fdisk_lba_is_phy_aligned(cxt, fdisk_partition_get_start(pa))) {
 			if (!post)
-				fdisk_info(cxt, ""); /* line break */
+				fdisk_info(cxt, "%s", ""); /* line break */
 			fdisk_warnx(cxt, _("Partition %zu does not start on physical sector boundary."),
 					  fdisk_partition_get_partno(pa) + 1);
 			post++;
 		}
 		if (fdisk_partition_has_wipe(cxt, pa)) {
 			if (!post)
-				fdisk_info(cxt, ""); /* line break */
-			 fdisk_info(cxt, _("Filesystem/RAID signature on partition %zu will be wiped."),
-					 fdisk_partition_get_partno(pa) + 1);
-			 post++;
+				fdisk_info(cxt, "%s", ""); /* line break */
+
+			fdisk_info(cxt, _("Filesystem/RAID signature on partition %zu will be wiped."),
+					fdisk_partition_get_partno(pa) + 1);
+			post++;
 		}
 	}
 
 	if (fdisk_table_wrong_order(tb)) {
 		if (!post)
-			fdisk_info(cxt, ""); /* line break */
+			fdisk_info(cxt, "%s", ""); /* line break */
 		fdisk_info(cxt, _("Partition table entries are not in disk order."));
 	}
 done:
@@ -217,32 +229,45 @@ done:
 	fdisk_free_iter(itr);
 }
 
-void list_freespace(struct fdisk_context *cxt)
+/*
+ * List freespace areas and if @tb0 not NULL then returns the table.  The
+ * @best0 returns number of the "best" area (may be used as default in some
+ * dialog).
+ *
+ * Returns: <0 on error, else number of free areas
+ */
+int list_freespace_get_table(struct fdisk_context *cxt,
+			struct fdisk_table **tb0,
+			size_t *best0)
 {
 	struct fdisk_table *tb = NULL;
-	struct fdisk_partition *pa = NULL;
+	struct fdisk_partition *pa = NULL, *best = NULL;
 	struct fdisk_iter *itr = NULL;
 	struct libscols_table *out = NULL;
 	const char *bold = NULL;
 	size_t i;
-	uintmax_t sumsize = 0, bytes = 0;
+	uintmax_t sumsize = 0, bytes = 0, nbest = 0;
 	char *strsz;
+	int rc = 0, ct = 0;
 
-	static const char *colnames[] = { N_("Start"), N_("End"), N_("Sectors"), N_("Size") };
+	static const char *const colnames[] = { N_("Start"), N_("End"), N_("Sectors"), N_("Size") };
 	static const int colids[] = { FDISK_FIELD_START, FDISK_FIELD_END, FDISK_FIELD_SECTORS, FDISK_FIELD_SIZE };
 
-	if (fdisk_get_freespaces(cxt, &tb))
+	rc = fdisk_get_freespaces(cxt, &tb);
+	if (rc)
 		goto done;
 
 	itr = fdisk_new_iter(FDISK_ITER_FORWARD);
 	if (!itr) {
 		fdisk_warn(cxt, _("failed to allocate iterator"));
+		rc = -ENOMEM;
 		goto done;
 	}
 
 	out = scols_new_table();
 	if (!out) {
 		fdisk_warn(cxt, _("failed to allocate output table"));
+		rc = -ENOMEM;
 		goto done;
 	}
 
@@ -252,66 +277,118 @@ void list_freespace(struct fdisk_context *cxt)
 	}
 
 	for (i = 0; i < ARRAY_SIZE(colnames); i++) {
-		struct libscols_column *co = scols_table_new_column(out, _(colnames[i]), 5, SCOLS_FL_RIGHT);
+		struct libscols_column *co;
 
-		if (!co)
+		if (tb0 && i == 0) {
+			co = scols_table_new_column(out, "#", 5, SCOLS_FL_RIGHT);
+			if (!co) {
+				rc = -ENOMEM;
+				goto done;
+			}
+		}
+
+		co = scols_table_new_column(out, _(colnames[i]), 5, SCOLS_FL_RIGHT);
+		if (!co) {
+			rc = -ENOMEM;
 			goto done;
+		}
 		if (bold)
 			scols_cell_set_color(scols_column_get_header(co), bold);
 	}
 
 	/* fill-in output table */
 	while (fdisk_table_next_partition(tb, itr, &pa) == 0) {
+		int col;
 		struct libscols_line *ln = scols_table_new_line(out, NULL);
-		char *data;
 
 		if (!ln) {
 			fdisk_warn(cxt, _("failed to allocate output line"));
 			goto done;
 		}
-		for (i = 0; i < ARRAY_SIZE(colids); i++) {
+		for (col = 0, i = 0; i < ARRAY_SIZE(colnames); col++, i++) {
+			char *data = NULL;
+
+			if (tb0 && i == 0) {
+				if (scols_line_sprintf(ln, i, "%d", ct + 1)) {
+					fdisk_warn(cxt, _("failed to add output data"));
+					rc = -ENOMEM;
+					goto done;
+				}
+				col++;
+			}
+
 			if (fdisk_partition_to_string(pa, cxt, colids[i], &data))
 				continue;
-			if (scols_line_refer_data(ln, i, data)) {
+			if (scols_line_refer_data(ln, col, data)) {
 				fdisk_warn(cxt, _("failed to add output data"));
+				rc = -ENOMEM;
 				goto done;
 			}
 		}
 
-		if (fdisk_partition_has_size(pa))
-			sumsize += fdisk_partition_get_size(pa);
+		if (fdisk_partition_has_size(pa)) {
+			uintmax_t sz = fdisk_partition_get_size(pa);;
+
+			sumsize += sz;
+
+			if (best0 &&
+			    (best == NULL || fdisk_partition_get_size(best) < sz)) {
+				nbest = ct;
+				best = pa;
+			}
+		}
+		ct++;
 	}
 
-	bytes = sumsize * fdisk_get_sector_size(cxt);
-	strsz = size_to_human_string(SIZE_SUFFIX_SPACE
-					   | SIZE_SUFFIX_3LETTER, bytes);
+	if (tb0 == NULL) {
+		bytes = sumsize * fdisk_get_sector_size(cxt);
+		strsz = size_to_human_string(SIZE_DECIMAL_2DIGITS
+					     | SIZE_SUFFIX_SPACE
+					     | SIZE_SUFFIX_3LETTER, bytes);
 
-	color_scheme_enable("header", UL_COLOR_BOLD);
-	fdisk_info(cxt,	_("Unpartitioned space %s: %s, %ju bytes, %ju sectors"),
-			fdisk_get_devname(cxt), strsz,
-			bytes, sumsize);
-	color_disable();
-	free(strsz);
+		color_scheme_enable("header", UL_COLOR_BOLD);
+		fdisk_info(cxt,	_("Unpartitioned space %s: %s, %ju bytes, %ju sectors"),
+				fdisk_get_devname(cxt), strsz,
+				bytes, sumsize);
+		color_disable();
+		free(strsz);
 
-	fdisk_info(cxt, _("Units: %s of %d * %ld = %ld bytes"),
-	       fdisk_get_unit(cxt, FDISK_PLURAL),
-	       fdisk_get_units_per_sector(cxt),
-	       fdisk_get_sector_size(cxt),
-	       fdisk_get_units_per_sector(cxt) * fdisk_get_sector_size(cxt));
+		fdisk_info(cxt, _("Units: %s of %d * %ld = %ld bytes"),
+		       fdisk_get_unit(cxt, FDISK_PLURAL),
+		       fdisk_get_units_per_sector(cxt),
+		       fdisk_get_sector_size(cxt),
+		       fdisk_get_units_per_sector(cxt) * fdisk_get_sector_size(cxt));
 
-	fdisk_info(cxt, _("Sector size (logical/physical): %lu bytes / %lu bytes"),
-				fdisk_get_sector_size(cxt),
-				fdisk_get_physector_size(cxt));
+		fdisk_info(cxt, _("Sector size (logical/physical): %lu bytes / %lu bytes"),
+					fdisk_get_sector_size(cxt),
+					fdisk_get_physector_size(cxt));
+	}
 
 	/* print */
 	if (!scols_table_is_empty(out)) {
-		fdisk_info(cxt, "");	/* line break */
+		fdisk_info(cxt, "%s", "");	/* line break */
 		scols_print_table(out);
 	}
+
+	rc = 0;
 done:
 	scols_unref_table(out);
-	fdisk_unref_table(tb);
 	fdisk_free_iter(itr);
+
+	if (tb0)
+		*tb0 = tb;
+	else
+		fdisk_unref_table(tb);
+
+	if (best0)
+		*best0 = nbest;
+
+	return rc < 0 ? rc : ct;
+}
+
+void list_freespace(struct fdisk_context *cxt)
+{
+	list_freespace_get_table(cxt, NULL, NULL);
 }
 
 char *next_proc_partition(FILE **f)
@@ -357,7 +434,8 @@ char *next_proc_partition(FILE **f)
 	return NULL;
 }
 
-int print_device_pt(struct fdisk_context *cxt, char *device, int warnme, int verify)
+int print_device_pt(struct fdisk_context *cxt, char *device, int warnme,
+		    int verify, int separator)
 {
 	if (fdisk_assign_device(cxt, device, 1) != 0) {	/* read-only */
 		if (warnme || errno == EACCES)
@@ -365,6 +443,9 @@ int print_device_pt(struct fdisk_context *cxt, char *device, int warnme, int ver
 		return -1;
 	}
 
+	if (separator)
+		fputs("\n\n", stdout);
+
 	list_disk_geometry(cxt);
 
 	if (fdisk_has_label(cxt)) {
@@ -376,7 +457,8 @@ int print_device_pt(struct fdisk_context *cxt, char *device, int warnme, int ver
 	return 0;
 }
 
-int print_device_freespace(struct fdisk_context *cxt, char *device, int warnme)
+int print_device_freespace(struct fdisk_context *cxt, char *device, int warnme,
+			   int separator)
 {
 	if (fdisk_assign_device(cxt, device, 1) != 0) {	/* read-only */
 		if (warnme || errno == EACCES)
@@ -384,6 +466,9 @@ int print_device_freespace(struct fdisk_context *cxt, char *device, int warnme)
 		return -1;
 	}
 
+	if (separator)
+		fputs("\n\n", stdout);
+
 	list_freespace(cxt);
 	fdisk_deassign_device(cxt, 1);
 	return 0;
@@ -392,30 +477,26 @@ int print_device_freespace(struct fdisk_context *cxt, char *device, int warnme)
 void print_all_devices_pt(struct fdisk_context *cxt, int verify)
 {
 	FILE *f = NULL;
-	int ct = 0;
+	int sep = 0;
 	char *dev;
 
 	while ((dev = next_proc_partition(&f))) {
-		if (ct)
-			fputs("\n\n", stdout);
-		if (print_device_pt(cxt, dev, 0, verify) == 0)
-			ct++;
+		print_device_pt(cxt, dev, 0, verify, sep);
 		free(dev);
+		sep = 1;
 	}
 }
 
 void print_all_devices_freespace(struct fdisk_context *cxt)
 {
 	FILE *f = NULL;
-	int ct = 0;
+	int sep = 0;
 	char *dev;
 
 	while ((dev = next_proc_partition(&f))) {
-		if (ct)
-			fputs("\n\n", stdout);
-		if (print_device_freespace(cxt, dev, 0) == 0)
-			ct++;
+		print_device_freespace(cxt, dev, 0, sep);
 		free(dev);
+		sep = 1;
 	}
 }
 
@@ -432,7 +513,7 @@ void list_available_columns(FILE *out)
 
 	termwidth = get_terminal_width(80);
 
-	fprintf(out, USAGE_COLUMNS);
+	fputs(USAGE_COLUMNS, out);
 
 	while (fdisk_next_label(cxt, &lb) == 0) {
 		size_t width = 6;	/* label name and separators */
@@ -462,21 +543,24 @@ void list_available_columns(FILE *out)
 static int fieldname_to_id(const char *name, size_t namesz)
 {
 	const struct fdisk_field *fl;
-	char buf[namesz + 1];
+	char *buf;
 
 	assert(name);
 	assert(namesz);
 	assert(fields_label);
 
-	memcpy(buf, name, namesz);
-	buf[namesz] = '\0';
+	buf = strndup(name, namesz);
+	if (!buf)
+		return -1;
 
 	fl = fdisk_label_get_field_by_name(fields_label, buf);
 	if (!fl) {
 		warnx(_("%s unknown column: %s"),
 				fdisk_label_get_name(fields_label), buf);
+		free(buf);
 		return -1;
 	}
+	free(buf);
 	return fdisk_field_get_id(fl);
 }
 
@@ -533,4 +617,3 @@ done:
 		*n = fields_nids;
 	return fields_ids;
 }
-
