@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 2012-2015 Karel Zak <kzak@redhat.com>
+ * No copyright is claimed.  This code is in the public domain; do with
+ * it what you wish.
  *
- * This file may be distributed under the terms of the
- * GNU Lesser General Public License.
+ * Written by Karel Zak <kzak@redhat.com> [2012]
  */
 #ifndef UTIL_LINUX_COLOR_NAMES_H
 #define UTIL_LINUX_COLOR_NAMES_H
@@ -41,4 +41,7 @@
 
 extern const char *color_sequence_from_colorname(const char *str);
 
+extern int color_is_sequence(const char *color);
+extern char *color_get_sequence(const char *color);
+
 #endif /* UTIL_LINUX_COLOR_NAMES_H */
