@@ -8,6 +8,7 @@
 #include <sys/stat.h>
 #include <sys/file.h>
 #include <sys/ioctl.h>
+#include <errno.h>
 #include <unistd.h>
 #include <stdint.h>
 
@@ -31,8 +32,10 @@
 # define EBADFD 77		/* File descriptor in bad state */
 #endif
 
+#include "all-io.h"
 #include "blkdev.h"
 #include "c.h"
+#include "cctype.h"
 #include "linux_version.h"
 #include "fileutils.h"
 #include "nls.h"
@@ -43,7 +46,7 @@ blkdev_valid_offset (int fd, off_t offset) {
 
 	if (lseek (fd, offset, 0) < 0)
 		return 0;
-	if (read (fd, &ch, 1) < 1)
+	if (read_all (fd, &ch, 1) < 1)
 		return 0;
 	return 1;
 }
@@ -56,23 +59,25 @@ int is_blkdev(int fd)
 
 off_t
 blkdev_find_size (int fd) {
-	uintmax_t high, low = 0;
+	off_t high, low = 0;
 
 	for (high = 1024; blkdev_valid_offset (fd, high); ) {
-		if (high == UINTMAX_MAX)
+		if (high == SINT_MAX(off_t)) {
+			errno = EFBIG;
 			return -1;
+		}
 
 		low = high;
 
-		if (high >= UINTMAX_MAX/2)
-			high = UINTMAX_MAX;
+		if (high >= SINT_MAX(off_t)/2)
+			high = SINT_MAX(off_t);
 		else
 			high *= 2;
 	}
 
 	while (low < high - 1)
 	{
-		uintmax_t mid = (low + high) / 2;
+		off_t mid = (low + high) / 2;
 
 		if (blkdev_valid_offset (fd, mid))
 			low = mid;
@@ -166,8 +171,10 @@ blkdev_get_size(int fd, unsigned long long *bytes)
 			*bytes = st.st_size;
 			return 0;
 		}
-		if (!S_ISBLK(st.st_mode))
+		if (!S_ISBLK(st.st_mode)) {
+			errno = ENOTBLK;
 			return -1;
+		}
 	}
 
 	*bytes = blkdev_find_size(fd);
@@ -378,14 +385,14 @@ int blkdev_lock(int fd, const char *devname, const char *lockmode)
 	if (!lockmode)
 		return 0;
 
-	if (strcasecmp(lockmode, "yes") == 0 ||
+	if (c_strcasecmp(lockmode, "yes") == 0 ||
 	    strcmp(lockmode, "1") == 0)
 		oper = LOCK_EX;
 
-	else if (strcasecmp(lockmode, "nonblock") == 0)
+	else if (c_strcasecmp(lockmode, "nonblock") == 0)
 		oper = LOCK_EX | LOCK_NB;
 
-	else if (strcasecmp(lockmode, "no") == 0 ||
+	else if (c_strcasecmp(lockmode, "no") == 0 ||
 		 strcmp(lockmode, "0") == 0)
 		return 0;
 	else {
