@@ -96,7 +96,7 @@ char *absolute_path(const char *path)
 		return NULL;
 
 	/* simple clean up */
-	if (startswith(path, "./"))
+	if (ul_startswith(path, "./"))
 		path += 2;
 	else if (strcmp(path, ".") == 0)
 		path = NULL;
