@@ -13,18 +13,13 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/time.h>
-#ifdef __linux__
+#ifdef HAVE_SYS_SYSCALL_H
 #include <sys/syscall.h>
 #endif
 #include "c.h"
 #include "randutils.h"
 #include "nls.h"
 
-#ifdef HAVE_TLS
-#define THREAD_LOCAL static __thread
-#else
-#define THREAD_LOCAL static
-#endif
 
 #ifdef HAVE_GETRANDOM
 # include <sys/random.h>
@@ -80,16 +75,11 @@ static void crank_random(void)
 
 int random_get_fd(void)
 {
-	int i, fd;
+	int fd;
 
 	fd = open("/dev/urandom", O_RDONLY | O_CLOEXEC);
 	if (fd == -1)
 		fd = open("/dev/random", O_RDONLY | O_NONBLOCK | O_CLOEXEC);
-	if (fd >= 0) {
-		i = fcntl(fd, F_GETFD);
-		if (i >= 0)
-			fcntl(fd, F_SETFD, i | FD_CLOEXEC);
-	}
 	crank_random();
 	return fd;
 }
@@ -196,7 +186,7 @@ const char *random_tell_source(void)
 	return _("getrandom() function");
 #else
 	size_t i;
-	static const char *random_sources[] = {
+	static const char *const random_sources[] = {
 		"/dev/urandom",
 		"/dev/random"
 	};
