@@ -2,7 +2,7 @@
  * No copyright is claimed.  This code is in the public domain; do with
  * it what you wish.
  *
- * Copyright (C) 2011 Karel Zak <kzak@redhat.com>
+ * Written by Karel Zak <kzak@redhat.com> [2011]
  */
 #include <ctype.h>
 #include <libgen.h>
@@ -11,6 +11,7 @@
 #include <unistd.h>
 
 #include "c.h"
+#include "cctype.h"
 #include "pathnames.h"
 #include "sysfs.h"
 #include "fileutils.h"
@@ -404,8 +405,8 @@ char *sysfs_blkdev_get_devchain(struct path_cxt *pc, char *buf, size_t bufsz)
 	ul_buffer_append_string(&tmp, _PATH_SYS_DEVBLOCK "/");
 	ul_buffer_append_data(&tmp, buf, ssz);
 
-	p = ul_buffer_get_data(&tmp, &sz, NULL);
-	if (p && sz < bufsz) {
+	p = ul_buffer_get_string(&tmp, &sz, NULL);
+	if (p && sz <= bufsz) {
 		memcpy(buf, p, sz);
 		res = buf;
 	}
@@ -467,6 +468,10 @@ static int sysfs_devchain_is_removable(char *chain)
 		/* append "/removable" to the path */
 		memcpy(chain + len, REMOVABLE_FILENAME, sizeof(REMOVABLE_FILENAME));
 
+		/* root of device hierarchy */
+		if (strcmp(chain, "/sys/dev/block" REMOVABLE_FILENAME) == 0)
+			break;
+
 		/* try to read it */
 		fd = open(chain, O_RDONLY);
 		if (fd != -1) {
@@ -572,7 +577,7 @@ int sysfs_blkdev_get_wholedisk(	struct path_cxt *pc,
 	tmp = uuid;
 	prefix = uuid ? strsep(&tmp, "-") : NULL;
 
-        if (prefix && strncasecmp(prefix, "part", 4) == 0)
+        if (prefix && c_strncasecmp(prefix, "part", 4) == 0)
             is_part = 1;
         free(uuid);
 
@@ -973,7 +978,7 @@ dev_t __sysfs_devname_to_devno(const char *prefix, const char *name, const char
 	/*
 	 * Read from /sys/block/<parent>/<partition>/dev
 	 */
-	if (!dev && parent && startswith(name, parent)) {
+	if (!dev && parent && ul_startswith(name, parent)) {
 		len = snprintf(buf, sizeof(buf),
 				"%s" _PATH_SYS_BLOCK "/%s/%s/dev",
 				prefix, _parent, _name);
