@@ -200,8 +200,10 @@ static char *evaluate_by_scan(const char *token, const char *value,
 
 	if (!c) {
 		char *cachefile = blkid_get_cache_filename(conf);
-		blkid_get_cache(&c, cachefile);
+		int rc = blkid_get_cache(&c, cachefile);
 		free(cachefile);
+		if (rc < 0)
+			return NULL;
 	}
 	if (!c)
 		return NULL;
@@ -222,6 +224,9 @@ static char *evaluate_by_scan(const char *token, const char *value,
  * @value: token data (e.g. "foo")
  * @cache: pointer to cache (or NULL when you don't want to re-use the cache)
  *
+* If the @value is NULL and @token is not in the NAME=value format, then return
+* a copy of the @token.
+ *
  * Returns: allocated string with a device name.
  */
 char *blkid_evaluate_tag(const char *token, const char *value, blkid_cache *cache)
@@ -234,9 +239,6 @@ char *blkid_evaluate_tag(const char *token, const char *value, blkid_cache *cach
 	if (!token)
 		return NULL;
 
-	if (!cache || !*cache)
-		blkid_init_debug(0);
-
 	DBG(EVALUATE, ul_debug("evaluating  %s%s%s", token, value ? "=" : "",
 		   value ? value : ""));
 
@@ -315,8 +317,6 @@ int main(int argc, char *argv[])
 		return EXIT_FAILURE;
 	}
 
-	blkid_init_debug(0);
-
 	res = blkid_evaluate_spec(argv[1], &cache);
 	if (res)
 		printf("%s\n", res);
