@@ -91,8 +91,6 @@ static int probe_silraid(blkid_probe pr,
 	uint64_t off;
 	struct silicon_metadata *sil;
 
-	if (pr->size < 0x10000)
-		return 1;
 	if (!S_ISREG(pr->mode) && !blkid_probe_is_wholedisk(pr))
 		return 1;
 
@@ -127,6 +125,7 @@ static int probe_silraid(blkid_probe pr,
 const struct blkid_idinfo silraid_idinfo = {
 	.name		= "silicon_medley_raid_member",
 	.usage		= BLKID_USAGE_RAID,
+	.minsz		= 0x10000,
 	.probefunc	= probe_silraid,
 	.magics		= BLKID_NONE_MAGIC
 };
