@@ -14,6 +14,7 @@
 #include "c.h"
 #include "nls.h"
 #include "strutils.h"
+#include "timeutils.h"
 #include "xalloc.h"
 
 #include "libsmartcols.h"
@@ -22,11 +23,6 @@
 
 enum { COL_NUM, COL_DATA, COL_TIME };
 
-static double time_diff(struct timeval *a, struct timeval *b)
-{
-	return (a->tv_sec - b->tv_sec) + (a->tv_usec - b->tv_usec) / 1E6;
-}
-
 /* add columns to the @tb */
 static void setup_columns(struct libscols_table *tb)
 {
@@ -45,18 +41,16 @@ fail:
 
 static struct libscols_line *add_line(struct libscols_table *tb, size_t i)
 {
-	char *p;
 	struct libscols_line *ln = scols_table_new_line(tb, NULL);
 
 	if (!ln)
 		err(EXIT_FAILURE, "failed to create output line");
 
-	xasprintf(&p, "%zu", i);
-	if (scols_line_refer_data(ln, COL_NUM, p))
+	if (scols_line_sprintf(ln, COL_NUM, "%zu", i))
 		goto fail;
 
-	xasprintf(&p, "data-%02zu-%02zu-%02zu-end", i + 1, i + 2, i + 3);
-	if (scols_line_refer_data(ln, COL_DATA, p))
+	if (scols_line_sprintf(ln, COL_DATA,  "data-%02zu-%02zu-%02zu-end",
+			       i + 1, i + 2, i + 3))
 		goto fail;
 
 	return ln;
@@ -112,7 +106,7 @@ int main(void)
 
 			/* Note that libsmartcols don't print \n for last line
 			 * in the table, but if you print a line somewhere in
-			 * the midle of the table you need
+			 * the middle of the table you need
 			 *
 			 *    scols_table_enable_nolinesep(tb, !done);
 			 *
