@@ -72,6 +72,8 @@ void scols_unref_column(struct libscols_column *cl)
 		list_del(&cl->cl_columns);
 		scols_reset_cell(&cl->header);
 		free(cl->color);
+		free(cl->uri);
+		ul_buffer_free_data(&cl->uri_buf);
 		free(cl->safechars);
 		free(cl->wrap_data);
 		free(cl->shellvar);
@@ -101,6 +103,8 @@ struct libscols_column *scols_copy_column(const struct libscols_column *cl)
 
 	if (scols_column_set_color(ret, cl->color))
 		goto err;
+	if (scols_column_set_uri(ret, cl->uri))
+		goto err;
 	if (scols_cell_copy_content(&ret->header, &cl->header))
 		goto err;
 
@@ -431,6 +435,45 @@ const char *scols_column_get_color(const struct libscols_column *cl)
 	return cl->color;
 }
 
+/**
+ * scols_column_set_uri:
+ * @cl: a pointer to a struct libscols_column instance
+ * @uri: URI string
+ *
+ * The default URI prefix for cells is used when creating hyperlinks. However,
+ * it can still be disabled for selected cells using scols_cell_disable_uri().
+ * See also scols_cell_set_uri().
+ *
+ * The final cell URI is composed of the column-uri, cell-uri, and cell-data.
+ * The column-uri and/or cell-uri must be set for this feature to be enabled.
+ *
+ * <informalexample>
+ * <programlisting>
+ * column-uri  cell-uri                  cell-data      final-URI                 link
+ * --------------------------------------------------------------------------------------------
+ *             file://host/path/foo.txt  foo            file://host/path/foo.txt  foo
+ * file://host /path/foo.txt             foo            file://host/path/foo.txt  foo
+ * file://host                           /path/foo.txt  file://host/path/foo.txt  /path/foo.txt
+ * </programlisting>
+ * </informalexample>
+ *
+ * Returns: 0, a negative value in case of an error.
+ */
+int scols_column_set_uri(struct libscols_column *cl, const char *uri)
+{
+	return strdup_to_struct_member(cl, uri, uri);
+}
+
+/**
+ * scols_column_get_uri:
+ * @cl: a pointer to a struct libscols_column instance
+ *
+ * Returns: The current URI setting of the column @cl.
+ */
+const char *scols_column_get_uri(const struct libscols_column *cl)
+{
+	return cl->uri;
+}
 
 /**
  * scols_wrapnl_nextchunk:
@@ -629,7 +672,7 @@ int scols_column_get_wrap_data(const struct libscols_column *cl,
 	return 0;
 }
 
-/*
+/**
  * scols_column_set_data_func:
  * @cl: a pointer to a struct libscols_column instance
  * @datafunc: function to return data
@@ -637,9 +680,9 @@ int scols_column_get_wrap_data(const struct libscols_column *cl,
  *
  * The table always keep data in strings in form that is printed on output, but
  * for some internal operations (like filters or counters) it needs to convert
- * the strings to usable data format. If this converion is not possible then
+ * the strings to usable data format. If this conversion is not possible then
  * application can define datafunc() callback to provide data for filters and counters.
-
+ *
  * The callback needs to return the data as pointer to void, and the data type
  * is defined by scols_column_set_data_type().
  *
@@ -834,7 +877,7 @@ int scols_column_is_customwrap(const struct libscols_column *cl)
  * @cl: a pointer to a struct libscols_column instance
  * @opts: options string
  *
- * Set properties from string, the string is comma seprated list, like
+ * Set properties from string, the string is comma separated list, like
  * "trunc,right,json=number", ...
  *
  * Returns: 0 on success, <0 on error
