@@ -1896,11 +1896,11 @@ static char *netlink_get_name(struct sock_xinfo *sock_xinfo,
 	const char *protocol = netlink_decode_protocol(nl->protocol);
 
 	if (nl->groups)
-		xasprintf(&str, "protocol=%s lport=%"PRIu16 " groups=%"PRIu32,
+		xasprintf(&str, "protocol=%s lport=%"PRIu32 " groups=%"PRIu32,
 			  protocol,
 			  nl->lportid, nl->groups);
 	else
-		xasprintf(&str, "protocol=%s lport=%"PRIu16,
+		xasprintf(&str, "protocol=%s lport=%"PRIu32,
 			  protocol,
 			  nl->lportid);
 	return str;
@@ -2373,7 +2373,7 @@ static void load_xinfo_from_proc_packet(ino_t netns_inode)
 		unsigned long inode;
 		struct packet_xinfo *pkt;
 
-		if (sscanf(line, "%*x %*d %" SCNu16 " %" SCNu16 " %u %*d %*d %*d %lu",
+		if (sscanf(line, "%*x %*d %" SCNu16 " %" SCNx16 " %u %*d %*d %*d %lu",
 			   &type, &protocol, &iface, &inode) < 4)
 			continue;
 
