@@ -366,8 +366,8 @@ static void __attribute__((__noreturn__)) usage(void)
 	fputs(_(" -t, --terminate <char>   define the string-termination character\n"), out);
 
 	fputs(USAGE_SEPARATOR, out);
-	printf(USAGE_HELP_OPTIONS(26));
-	printf(USAGE_MAN_TAIL("look(1)"));
+	fprintf(out, USAGE_HELP_OPTIONS(26));
+	fprintf(out, USAGE_MAN_TAIL("look(1)"));
 
 	exit(EXIT_SUCCESS);
 }
