@@ -100,7 +100,7 @@ struct wh_dirlist {
 	struct wh_dirlist *next;
 };
 
-static const char *bindirs[] = {
+static const char *const bindirs[] = {
 	"/usr/bin",
 	"/usr/sbin",
 	"/bin",
@@ -161,7 +161,7 @@ static const char *bindirs[] = {
 	NULL
 };
 
-static const char *mandirs[] = {
+static const char *const mandirs[] = {
 	"/usr/man/*",
 	"/usr/share/man/*",
 	"/usr/X386/man/*",
@@ -172,7 +172,7 @@ static const char *mandirs[] = {
 	NULL
 };
 
-static const char *srcdirs[] = {
+static const char *const srcdirs[] = {
 	"/usr/src/*",
 	"/usr/src/lib/libc/*",
 	"/usr/src/lib/libc/net/*",
@@ -269,7 +269,7 @@ static void dirlist_add_subdir(struct wh_dirlist **ls, int type, const char *dir
 	char buf[PATH_MAX], *d;
 	DIR *dirp;
 	struct dirent *dp;
-	char *postfix;
+	const char *postfix;
 	size_t len;
 
 	postfix = strchr(dir, '*');
@@ -355,7 +355,7 @@ static void construct_dirlist_from_argv(struct wh_dirlist **ls,
 
 static void construct_dirlist(struct wh_dirlist **ls,
 			      int type,
-			      const char **paths)
+			      const char *const*paths)
 {
 	size_t i;
 
@@ -471,13 +471,14 @@ static void findin(const char *dir, const char *pattern, int *count,
 
 static void lookup(const char *pattern, struct wh_dirlist *ls, int want)
 {
-	char patbuf[PATH_MAX];
+	char patbuf[PATH_MAX] = { 0 };
 	int count = 0;
-	char *wait = NULL, *p;
+	char *wait = NULL;
+	const char *p;
 
 	/* canonicalize pattern -- remove path suffix etc. */
 	p = strrchr(pattern, '/');
-	p = p ? p + 1 : (char *) pattern;
+	p = p ? p + 1 : pattern;
 	xstrncpy(patbuf, p, PATH_MAX);
 
 	DBG(SEARCH, ul_debug("lookup dirs for '%s' (%s), want: %s %s %s",
