@@ -40,6 +40,7 @@
 #include "all-io.h"
 #include "match.h"
 #include "c.h"
+#include "cctype.h"
 #include "closestream.h"
 #include "optutils.h"
 #include "blkdev.h"
@@ -126,7 +127,7 @@ static int column_name_to_id(const char *name, size_t namesz)
 
 	for (i = 0; i < ARRAY_SIZE(infos); i++) {
 		const char *cn = infos[i].name;
-		if (!strncasecmp(name, cn, namesz) && !*(cn + namesz))
+		if (!c_strncasecmp(name, cn, namesz) && !*(cn + namesz))
 			return i;
 	}
 	warnx(_("unknown column: %s"), name);
@@ -710,6 +711,8 @@ main(int argc, char **argv)
 			break;
 		case 'b':
 			if (optarg) {
+				if (*optarg == '=')
+					optarg++;
 				ctl.backup = optarg;
 			} else {
 				ctl.backup = getenv("HOME");
