@@ -149,7 +149,7 @@ static int init_device(struct blkzone_control *ctl, int mode)
 		errx(EXIT_FAILURE, _("%s: not a block device"), ctl->devname);
 
 	if (blkdev_get_sectors(fd, (unsigned long long *) &ctl->total_sectors))
-		err(EXIT_FAILURE, _("%s: blkdev_get_sectors ioctl failed"), ctl->devname);
+		err(EXIT_FAILURE, _("%s: failed to get number of sectors"), ctl->devname);
 
 	if (blkdev_get_sector_size(fd, &ctl->secsize))
 		err(EXIT_FAILURE, _("%s: BLKSSZGET ioctl failed"), ctl->devname);
@@ -207,14 +207,14 @@ done:
  */
 #define DEF_REPORT_LEN		(1U << 12) /* 4k zones per report (256k kzalloc) */
 
-static const char *type_text[] = {
+static const char *const type_text[] = {
 	"RESERVED",
 	"CONVENTIONAL",
 	"SEQ_WRITE_REQUIRED",
 	"SEQ_WRITE_PREFERRED",
 };
 
-static const char *condition_str[] = {
+static const char *const condition_str[] = {
 	"nw", /* Not write pointer */
 	"em", /* Empty */
 	"oi", /* Implicitly opened */
