@@ -168,7 +168,7 @@ function ts_skip_nonroot {
 #	ts_skip_capability cap_wake_alarm
 #
 function ts_skip_capability {
-	ts_check_prog "$TS_HELPER_CAP"
+	ts_check_test_command "$TS_HELPER_CAP"
 
 	if ! "$TS_HELPER_CAP" "$1"; then
 		ts_skip "no capability: $1"
@@ -312,8 +312,13 @@ function ts_init_env {
 	CHARSET="UTF-8"
 	ASAN_OPTIONS="detect_leaks=0"
 	UBSAN_OPTIONS="print_stacktrace=1:print_summary=1:halt_on_error=1"
+	KERNEL_VERSION_XYZ=$(uname -r | awk -F- '{print $1}')
+	KERNEL_VERSION_MAJOR=$(echo "$KERNEL_VERSION_XYZ" | awk -F. '{print $1}')
+	KERNEL_VERSION_MINOR=$(echo "$KERNEL_VERSION_XYZ" | awk -F. '{print $2}')
+	KERNEL_RELEASE=$(echo "$KERNEL_VERSION_XYZ" | awk -F. '{print $3}')
 
-	export LANG LANGUAGE LC_ALL CHARSET ASAN_OPTIONS UBSAN_OPTIONS
+	export LANG LANGUAGE LC_ALL CHARSET ASAN_OPTIONS UBSAN_OPTIONS \
+	       KERNEL_VERSION_XYZ KERNEL_VERSION_MAJOR KERNEL_VERSION_MINOR KERNEL_RELEASE
 
 	mydir=$(ts_canonicalize "$mydir")
 
@@ -641,6 +646,27 @@ function ts_skip_subtest {
 
 }
 
+# Specify the kernel version X.Y.Z you wish to compare against like:
+#
+#	ts_kernel_ver_lt X Y Z
+#
+function ts_kernel_ver_lt {
+	if [ $KERNEL_VERSION_MAJOR -lt $1 ]; then
+		return 0
+	elif [ $KERNEL_VERSION_MAJOR -eq $1 ]; then
+		if [ $KERNEL_VERSION_MINOR -lt $2 ]; then
+			return 0
+		elif [ $KERNEL_VERSION_MINOR -eq $2 ]; then
+			if [ $KERNEL_RELEASE -lt $3 ]; then
+				return 0
+			fi
+		fi
+
+	fi
+
+	return 1
+}
+
 function ts_finalize {
 	ts_cleanup_on_exit
 
@@ -788,6 +814,21 @@ function ts_device_has {
 	return $res
 }
 
+# Based on __SYSMACROS_DEFINE_MAKEDEV macro
+# defined in /usr/include/bits/sysmacros.h of GNU libc.
+function ts_makedev
+{
+	local major="$1"
+	local minor="$2"
+	local dev
+
+	dev=$((      ( major & 0x00000fff ) <<  8))
+	dev=$((dev | ( major & 0xfffff000 ) << 32))
+	dev=$((dev | ( minor & 0x000000ff ) <<  0))
+	dev=$((dev | ( minor & 0xffffff00 ) << 12))
+	echo $dev
+}
+
 function ts_is_uuid()
 {
 	printf "%s\n" "$1" | grep -E -q '^[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{12}$'
@@ -1180,3 +1221,9 @@ function ts_check_enosys_syscalls {
 function ts_skip_docker {
 	test -e /.dockerenv && ts_skip "unsupported in docker environment"
 }
+
+function ts_check_ipv6 {
+       if [ ! -e /proc/net/if_inet6 ]; then
+               ts_skip "IPv6 is not supported"
+       fi
+}
